@@ -1,4 +1,5 @@
 
+import os
 import sys
 import logging
 
@@ -10,8 +11,11 @@ app.config.from_object('alerta.settings')
 app.config.from_pyfile('/etc/alertad.conf', silent=True)
 app.config.from_envvar('ALERTA_SVR_CONF_FILE', silent=True)
 
+if 'SECRET_KEY' in os.environ:
+    app.config['SECRET_KEY'] = os.environ['SECRET_KEY']
+
 if app.config['USE_STDERR']:
-    stderr_hanlder = logging.StreamHandler(stream=sys.stderr)
+    stderr_hanlder = logging.StreamHandler()
     stderr_hanlder.setFormatter(logging.Formatter(fmt=app.config['LOG_FORMAT']))
     app.logger.addHandler(stderr_hanlder)
 
@@ -30,9 +34,8 @@ if app.debug:
 else:
     app.logger.setLevel(logging.WARNING)
 
-from alerta.app.database import Mongo
-
-db = Mongo()
+from alerta.app.mongo_backend import MongoBackend
+db = MongoBackend()
 
 import views
 import management.views
