@@ -9,7 +9,6 @@ import hashlib
 import pymongo
 
 from alerta.app import app, severity_code, status_code
-
 from alerta.alert import AlertDocument
 from alerta.heartbeat import HeartbeatDocument
 
@@ -27,18 +26,38 @@ class Mongo(object):
 
     def connect(self):
 
-        if 'MONGO_PORT' in os.environ and 'tcp://' in os.environ['MONGO_PORT']:  # used by linked Docker containers
+        if 'MONGO_PORT' in os.environ and 'tcp://' in os.environ['MONGO_PORT']:  # Docker
             host, port = os.environ['MONGO_PORT'][6:].split(':')
-            app.config['MONGO_HOST'] = host
-            app.config['MONGO_PORT'] = int(port)
+            try:
+                self.conn = pymongo.MongoClient(host, port)
+            except Exception, e:
+                LOG.error('MongoDB Client connection error - %s : %s', os.environ['MONGO_PORT'], e)
+                sys.exit(1)
 
-        if not app.config['MONGO_REPLSET']:
+        elif 'MONGOHQ_URL' in os.environ:
+            try:
+                self.conn = pymongo.MongoClient(os.environ['MONGOHQ_URL'])
+            except Exception, e:
+                LOG.error('MongoDB Client connection error - %s : %s', os.environ['MONGOHQ_URL'], e)
+                sys.exit(1)
+            app.config['MONGO_DATABASE'] = os.environ['MONGOHQ_URL'].split('/')[-1]
+
+        elif 'MONGOLAB_URI' in os.environ:
+            try:
+                self.conn = pymongo.MongoClient(os.environ['MONGOLAB_URI'])
+            except Exception, e:
+                LOG.error('MongoDB Client connection error - %s : %s', os.environ['MONGOLAB_URI'], e)
+                sys.exit(1)
+            app.config['MONGO_DATABASE'] = os.environ['MONGOLAB_URI'].split('/')[-1]
+
+        elif not app.config['MONGO_REPLSET']:
             try:
                 self.conn = pymongo.MongoClient(app.config['MONGO_HOST'], app.config['MONGO_PORT'])
             except Exception, e:
                 LOG.error('MongoDB Client connection error - %s:%s : %s', app.config['MONGO_HOST'], app.config['MONGO_PORT'], e)
                 sys.exit(1)
             LOG.info('Connected to mongodb://%s:%s/%s', app.config['MONGO_HOST'], app.config['MONGO_PORT'], app.config['MONGO_DATABASE'])
+
         else:
             try:
                 self.conn = pymongo.MongoClient(app.config['MONGO_HOST'], app.config['MONGO_PORT'], replicaSet=app.config['MONGO_REPLSET'])
@@ -60,7 +79,8 @@ class Mongo(object):
 
         LOG.info('Available MongoDB collections: %s', ','.join(self.db.collection_names()))
 
-        self.create_indexes()
+        if app.config['MONGO_REPLSET']:
+            self.create_indexes()
 
     def create_indexes(self):
 
@@ -129,6 +149,9 @@ class Mongo(object):
 
     def get_alerts(self, query=None, fields=None, sort=None, limit=0):
 
+        if 'status' not in query:
+            query = {"status": {'$ne': "expired"}}
+
         responses = self.db.alerts.find(query, fields=fields, sort=sort).limit(limit)
 
         alerts = list()
@@ -678,12 +701,25 @@ class Mongo(object):
 
         return response.get('ok', False) and response.get('n', 0) == 1
 
-    def get_counts(self, query=None):
+    def get_counts(self, query=None, fields=None, group=None):
         """
-        Return total and dict() of severity and status counts.
+        Return counts grouped by severity or status.
         """
+        fields = fields or {}
 
-        return self.db.alerts.find(query, {"severity": 1, "status": 1})
+        pipeline = [
+            {'$match': query},
+            {'$project': fields},
+            {'$group': {"_id": "$" + group, "count": {'$sum': 1}}}
+        ]
+
+        responses = self.db.alerts.aggregate(pipeline)
+
+        counts = dict()
+        for response in responses['result']:
+            counts[response['_id']] = response['count']
+
+        return counts
 
     def get_topn(self, query=None, group=None, limit=10):
 
